@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "reazon" "0.4.1"
+(define-package "reazon" "20260101.1930"
   "MiniKanren for Emacs."
   '((emacs "26"))
   :url "https://github.com/nickdrozd/reazon"
-  :commit "21a4218538eee90af66c20519457efeb5b319e22"
-  :revdesc "21a4218538ee"
+  :commit "377e879202943eba10b812f372d6cb00aa344fe9"
+  :revdesc "377e87920294"
   :keywords '("languages" "extensions" "lisp")
   :authors '(("Nick Drozd" . "nicholasdrozd@gmail.com"))
   :maintainers '(("Nick Drozd" . "nicholasdrozd@gmail.com")))
